@@ -22,7 +22,7 @@ import datetime
 import functools
 import bz2
 
-import xml.etree.ElementTree as ET
+from calculate.lib.cl_xml import ET
 import pexpect
 from calculate.lib.configparser import ConfigParser
 
