@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2008-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2008-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -18,11 +18,10 @@ import os
 import sys
 from os import path
 from itertools import *
-from calculate.lib.datavars import (TableVariable,Variable,ReadonlyVariable,
-                                   VariableError, ReadonlyTableVariable,
-                                   FieldValue)
-import calculate.lib.cl_template as cl_template
-from calculate.lib.utils.files import listDirectory,process,PIPE,pathJoin
+from calculate.lib.datavars import (TableVariable, Variable, ReadonlyVariable,
+                                    VariableError, ReadonlyTableVariable,
+                                    FieldValue, HumanReadable)
+from calculate.lib.utils.files import listDirectory, process, PIPE, pathJoin
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.common import cmpVersion
 from itertools import dropwhile
@@ -31,19 +30,22 @@ import contextlib
 import multiprocessing
 from collections import namedtuple
 
+_ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
 
-setLocalTranslate('cl_lib3',sys.modules[__name__])
+setLocalTranslate('cl_lib3', sys.modules[__name__])
 
 _envData = [('system', '/etc/calculate/calculate.env'),
             ('local', '/var/calculate/calculate.env'),
             ('remote', '/var/calculate/remote/calculate.env')]
 
+
 class VariableClEnvData(TableVariable):
     """
     Aliases and path to ini files
     """
-    source = ["cl_env_location","cl_env_path"]
+    source = ["cl_env_location", "cl_env_path"]
+
 
 class VariableClEnvLocation(ReadonlyVariable):
     """
@@ -52,6 +54,7 @@ class VariableClEnvLocation(ReadonlyVariable):
     type = 'list'
     value = list(zip(*_envData)[0])
 
+
 class VariableClEnvPath(Variable):
     """
     Path to ini files (from cl_env_data)
@@ -59,18 +62,20 @@ class VariableClEnvPath(Variable):
     type = 'list'
     value = list(zip(*_envData)[1])
 
+
 class VariableClTemplateData(TableVariable):
     """
     Aliases to templates path
     """
-    source = ["cl_template_location","cl_template_path"]
+    source = ["cl_template_location", "cl_template_path"]
+
 
 class VariableClTemplateLocation(Variable):
     """
     Name to templates
     """
     type = 'list'
-    value = ["overlay","local","remote"]
+    value = ["overlay", "local", "remote"]
 
 
 class VariableClTemplatePath(Variable):
@@ -82,12 +87,14 @@ class VariableClTemplatePath(Variable):
              "/var/calculate/templates",
              "/var/calculate/remote/templates"]
 
+
 class VariableClEnvServerPath(ReadonlyVariable):
     """
     Path to server environment
     """
     value = '/var/calculate/remote/server.env'
 
+
 class VariableClTemplateCltPath(ReadonlyVariable):
     """
     Paths to clt-template files
@@ -100,14 +107,16 @@ class VariableClTemplateCltPath(ReadonlyVariable):
         """
         chroot = self.Get('cl_chroot_path')
         if "CONFIG_PROTECT" in os.environ:
-            protectPaths = ["/etc"] + filter(lambda x: x.strip(),
-                                      os.environ["CONFIG_PROTECT"].split(" "))
+            protect_paths = ["/etc"] + filter(
+                lambda x: x.strip(),
+                os.environ["CONFIG_PROTECT"].split(" "))
         else:
-            protectPaths = ["/etc", "/usr/share/X11/xkb", "var/lib/hsqldb",
-                            "/usr/share/config"]
-        return filter(path.exists, 
-               map(lambda x:pathJoin(chroot,x),
-               protectPaths))
+            protect_paths = ["/etc", "/usr/share/X11/xkb", "var/lib/hsqldb",
+                             "/usr/share/config"]
+        return filter(path.exists,
+                      map(lambda x: pathJoin(chroot, x),
+                          protect_paths))
+
 
 class VariableClRootPath(Variable):
     """
@@ -116,41 +125,49 @@ class VariableClRootPath(Variable):
     """
     value = '/'
 
+
 class VariableClRootPathNext(Variable):
     """
     Path to directory relative which perform joining templates to system files
     (sandbox). This set for configure packages specified throug merge=
     """
+
     def get(self):
         return self.Get('cl_root_path')
 
+
 class VariableClChrootPath(ReadonlyVariable):
     """
     Path to directory which contain other system
     """
     value = '/'
 
+
 class VariableClPassStep(Variable):
     """
     Pass for templates join 1,2,3,4,5 and etc
     """
 
+
 class VariableClTaskName(ReadonlyVariable):
     """
     Название задачи выполняемой cl-core
     """
 
+
 class VariableClPassFile(Variable):
     """
     Template file performed at now
     """
 
+
 class VariableClPassLocation(Variable):
     """
     Текущая обрабатываемая локация
     """
     value = ""
 
+
 class VariableClSetupSkipProfile(Variable):
     """
     Список пакетов и местоположения шаблонов пропускаемых
@@ -159,6 +176,7 @@ class VariableClSetupSkipProfile(Variable):
     type = "table"
     value = [[]]
 
+
 class VariableClSetupSkipPatch(Variable):
     """
     Список пакетов и местоположения шаблонов пропускаемых
@@ -167,6 +185,7 @@ class VariableClSetupSkipPatch(Variable):
     type = "table"
     value = [[]]
 
+
 class VariableClSetupSkipMerge(Variable):
     """
     Список пакетов и местоположения шаблонов пропускаемых
@@ -175,6 +194,7 @@ class VariableClSetupSkipMerge(Variable):
     type = "table"
     value = [[]]
 
+
 class VariableClMergeSet(ReadonlyVariable):
     """
     Force by package template appling
@@ -182,6 +202,7 @@ class VariableClMergeSet(ReadonlyVariable):
     type = "bool"
     value = "off"
 
+
 class VariableClMergePkg(ReadonlyVariable):
     """
     This variable work with template function belong(package_name)
@@ -191,27 +212,32 @@ class VariableClMergePkg(ReadonlyVariable):
     (package_name == value of cl_belong_pkg)
     """
     type = "list"
+
     def get(self):
         return self.Get('cl_belong_pkg')
 
+
 class VariableClMergePkgNew(ReadonlyVariable):
     """
     New variable value for cl_merge_pkg
     """
     type = "list"
 
+
 class VariableClMergePkgPass(ReadonlyVariable):
     """
     Performed packages
     """
     type = "list"
 
+
 class VariableClBelongPkg(ReadonlyVariable):
     """
     Depricated by cl_merge_pkg
     """
     type = "list"
 
+
 class VariableClAction(ReadonlyVariable):
     """
     Program action
@@ -225,6 +251,7 @@ class VariableClPassState(ReadonlyVariable):
     specifies addition to cl_pass_action for needing
     """
 
+
 class VariableClMerges(Variable):
     """
     Programs have templates setup
@@ -234,9 +261,10 @@ class VariableClMerges(Variable):
     def get(self):
         return []
 
-    def set(self,value):
+    def set(self, value):
         return []
 
+
 class VariableClAutoupdateSet(Variable):
     """
     (on or off) autoupdate config from install program
@@ -249,6 +277,7 @@ class VariableClAutoupdateSet(Variable):
         else:
             return "off"
 
+
 class VariableClHumanEditSet(Variable):
     """
     Параметр для отметки "ручной правки"
@@ -261,6 +290,7 @@ class VariableClHumanEditSet(Variable):
         self.help = _("mark as human modification")
         self.label = _("Mark as human modification")
 
+
 class VariableClProtectUseSet(ReadonlyVariable):
     """
     Использовать portage интеграцию с конфигурационными файлами
@@ -270,12 +300,14 @@ class VariableClProtectUseSet(ReadonlyVariable):
     def get(self):
         return "on" if self.Get('cl_human_edit_set') == 'off' else "off"
 
+
 class VariableClDispatchConfDefault(Variable):
     """
     Используется для обхода экспертных параметров
     """
     value = "dispatch"
 
+
 class VariableClDispatchConf(Variable):
     """
 
@@ -286,8 +318,8 @@ class VariableClDispatchConf(Variable):
     metavalue = "METHOD"
 
     def init(self):
-        self.help = "'usenew' - " +_("use the new config files") +\
-                    ",\n'skip' - " + _("skip the update of config files") +\
+        self.help = "'usenew' - " + _("use the new config files") + \
+                    ",\n'skip' - " + _("skip the update of config files") + \
                     ",\n'dispatch' - " + _("manually update config files")
         self.label = _("Method for updating config files")
 
@@ -295,9 +327,10 @@ class VariableClDispatchConf(Variable):
         return self.Get('cl_dispatch_conf_default')
 
     def choice(self):
-        return [("usenew",_("Use the new config files")),
-                ("skip",_("Skip the update of config files")),
-                ("dispatch",_("Manually update config files"))]
+        return [("usenew", _("Use the new config files")),
+                ("skip", _("Skip the update of config files")),
+                ("dispatch", _("Manually update config files"))]
+
 
 class VariableClWsdl(Variable):
     """
@@ -308,23 +341,28 @@ class VariableClWsdl(Variable):
     def choice(self):
         return self.Get('cl_wsdl_available')
 
+
 class VariableClWsdlAvailable(ReadonlyVariable):
     """
     Packages which has wsdl interfaces
     """
     type = "list"
-    
+
     def get(self):
-        sitePackages = map(lambda x:path.join(x,"calculate"),
-                       filter(lambda x:x.endswith('site-packages') and \
-                                       x.startswith('/usr/lib'),sys.path))
-        retList = []
-        for module,modDir in chain(*map(lambda x:map(lambda y:(path.basename(y),y),
-                             listDirectory(x,True,True)),sitePackages)):
-            if path.exists(path.join(modDir,"wsdl_%s.py"%module)):
-                if not "calculate-%s"%module in retList:
-                    retList.append("calculate-%s"%module)
-        return retList
+        site_packages = [path.join(x, "calculate")
+                         for x in sys.path
+                         if (x.endswith('site-packages') and
+                             x.startswith('/usr/lib'))]
+        ret_list = []
+        for module, modDir in chain(
+                *map(lambda x: map(lambda y: (path.basename(y), y),
+                                   listDirectory(x, True, True)),
+                     site_packages)):
+            if path.exists(path.join(modDir, "wsdl_%s.py" % module)):
+                if not "calculate-%s" % module in ret_list:
+                    ret_list.append("calculate-%s" % module)
+        return ret_list
+
 
 class VariableClConfigProtectMask(ReadonlyVariable):
     """
@@ -336,15 +374,16 @@ class VariableClConfigProtectMask(ReadonlyVariable):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "CONFIG_PROTECT_MASK" in emerge_config:
             return emerge_config['CONFIG_PROTECT_MASK'].encode('utf-8').split()
-        displayEnv = process('/bin/bash',"-c","source /etc/profile;env",
-                             stdout=PIPE)
-        for line in displayEnv:
+        display_env = process('/bin/bash', "-c", "source /etc/profile;env",
+                              stdout=PIPE)
+        for line in display_env:
             if line.startswith("CONFIG_PROTECT_MASK="):
-                configProtectMask=line.rstrip().partition('=')[2].split()
+                config_protect_mask = line.rstrip().partition('=')[2].split()
                 break
         else:
-            configProtectMask = []
-        return configProtectMask
+            config_protect_mask = []
+        return config_protect_mask
+
 
 class VariableClConfigProtect(ReadonlyVariable):
     """
@@ -356,16 +395,16 @@ class VariableClConfigProtect(ReadonlyVariable):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "CONFIG_PROTECT" in emerge_config:
             return emerge_config['CONFIG_PROTECT'].encode('utf-8').split()
-        displayEnv = process('/bin/bash',"-c","source /etc/profile;env",
-                             stdout=PIPE)
-        for line in displayEnv:
+        display_env = process('/bin/bash', "-c", "source /etc/profile;env",
+                              stdout=PIPE)
+        for line in display_env:
             if line.startswith("CONFIG_PROTECT="):
-                configProtect=line.rstrip().partition('=')[2].split()
+                config_protect = line.rstrip().partition('=')[2].split()
                 break
         else:
-            configProtect = []
-        configProtect.append('/etc')
-        return configProtect
+            config_protect = []
+        config_protect.append('/etc')
+        return config_protect
 
 
 class VariableClVerboseSet(Variable):
@@ -380,17 +419,20 @@ class VariableClVerboseSet(Variable):
         self.help = _("verbose output")
         self.label = _("Verbose output")
 
+
 class VariableClEbuildPhase(ReadonlyVariable):
     """
     Current ebuild phase
     """
+
     def get(self):
-        return os.environ.get("EBUILD_PHASE","")
+        return os.environ.get("EBUILD_PHASE", "")
+
 
 class EmergeInfoData:
     def __init__(self):
-        self.data = process("/usr/bin/emerge","--ask=n","--info",
-                       envdict=os.environ).read().split('\n')
+        self.data = process("/usr/bin/emerge", "--ask=n", "--info",
+                            envdict=os.environ).read().split('\n')
 
     def __iter__(self):
         return iter(self.data)
@@ -398,6 +440,7 @@ class EmergeInfoData:
     def __str__(self):
         return "emerge --info"
 
+
 class VariableClEmergeInfo(ReadonlyVariable):
     """
     Emerge --info cache
@@ -407,6 +450,7 @@ class VariableClEmergeInfo(ReadonlyVariable):
     def get(self):
         return EmergeInfoData()
 
+
 class VariableClPkgdir(ReadonlyVariable):
     """
     PKGDIR
@@ -417,12 +461,13 @@ class VariableClPkgdir(ReadonlyVariable):
         if emerge_config and "PKGDIR" in emerge_config:
             return emerge_config['PKGDIR'].encode('utf-8')
         else:
-            emergeInfo = self.Get('cl_emerge_info')
+            emerge_info = self.Get('cl_emerge_info')
             for line in filter(lambda x: x.startswith("PKGDIR="),
-                               emergeInfo):
+                               emerge_info):
                 return line.partition("=")[2].strip('\n"\'')
         return ""
 
+
 class VariableClFeatures(ReadonlyVariable):
     """
     PKGDIR
@@ -435,23 +480,26 @@ class VariableClFeatures(ReadonlyVariable):
             return filter(
                 None, emerge_config['FEATURES'].encode('utf-8').split())
         else:
-            emergeInfo = self.Get('cl_emerge_info')
+            emerge_info = self.Get('cl_emerge_info')
             for line in filter(lambda x: x.startswith("FEATURES="),
-                               emergeInfo):
+                               emerge_info):
                 return filter(
                     None, line.partition("=")[2].strip('\n"\'').split())
         return ""
 
+
 class VariableClDistdir(ReadonlyVariable):
     """
     DISTDIR
     """
+
     def get(self):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "DISTDIR" in emerge_config:
             return emerge_config['DISTDIR'].encode('utf-8')
         return "/var/calculate/remote/distfiles"
 
+
 class VariableClRepositoryData(ReadonlyTableVariable):
     """
     """
@@ -466,57 +514,63 @@ class VariableClRepositoryData(ReadonlyTableVariable):
 
     def parse_repository_block(self, i):
         text = "\n".join(i)
-        reBlock = re.compile("^(\w+)$\n\s+location: (.*)$", re.M)
-        return reBlock.findall(text)
+        re_block = re.compile("^(\w+)$\n\s+location: (.*)$", re.M)
+        return re_block.findall(text)
 
     def from_portdir_vars(self, info):
-        for line in filter(lambda x:x.startswith("PORTDIR="),
+        for line in filter(lambda x: x.startswith("PORTDIR="),
                            info):
             yield ["gentoo", line.partition("=")[2].strip('\n"\'')]
 
-        emergeInfo = self.Get('cl_emerge_info')
-        for line in filter(lambda x:x.startswith("PORTDIR_OVERLAY="),
-                    info):
-            for i in ([path.basename(x),x]
-                for x in line.partition("=")[2].strip('\n"\'').split(' ')
-                if x):
+        self.Get('cl_emerge_info')
+        for line in filter(lambda x: x.startswith("PORTDIR_OVERLAY="),
+                           info):
+            for i in ([path.basename(x), x]
+                      for x in line.partition("=")[2].strip('\n"\'').split(' ')
+                      if x):
                 yield i
 
-    def get(self):
+    def get(self, hr=HumanReadable.No):
         emerge_config = self.Get('cl_emerge_config')
         if emerge_config and "PKGDIR" in emerge_config:
-            return [[repo.name.encode('UTF-8'),repo.location.encode('UTF-8')]
-                for repo in emerge_config.repositories]
+            return [[repo.name.encode('UTF-8'), repo.location.encode('UTF-8')]
+                    for repo in emerge_config.repositories]
         else:
             info = self.Get("cl_emerge_info")
             if self.portage_ver_ge("2.2.18"):
                 return self.parse_repository_block(
-                    dropwhile(lambda x:not x.startswith("Repositories:"), info))
+                    dropwhile(lambda x: not x.startswith("Repositories:"),
+                              info))
             return list(self.from_portdir_vars(info))
 
-class VariableClRepositoryName(FieldValue,ReadonlyVariable):
+
+class VariableClRepositoryName(FieldValue, ReadonlyVariable):
     """
     """
     type = "list"
     source_variable = "cl_repository_data"
     column = 0
 
-class VariableClRepositoryLocation(FieldValue,ReadonlyVariable):
+
+class VariableClRepositoryLocation(FieldValue, ReadonlyVariable):
     """
     """
     type = "list"
     source_variable = "cl_repository_data"
     column = 1
 
+
 class VariableClPortdir(ReadonlyVariable):
     """
     PORTDIR
     """
+
     def get(self):
         return self.Select('cl_repository_location',
                            where='cl_repository_name',
                            eq="gentoo", limit=1) or ""
 
+
 class VariableClPortdirOverlay(ReadonlyVariable):
     """
     Overlays path
@@ -531,15 +585,17 @@ class VariableClPortdirOverlay(ReadonlyVariable):
 
 RepoConfigProxy = namedtuple("RepoConfigProxy", ["name", "location"])
 
+
 @contextlib.contextmanager
 def stderr_devnull():
     oldstderr = sys.stderr
-    sys.stderr = open(os.devnull,'w')
+    sys.stderr = open(os.devnull, 'w')
     try:
         yield
     finally:
         sys.stderr = oldstderr
 
+
 class PortageConfigProxy(object):
     def __init__(self):
         self._dict = {}
@@ -571,8 +627,9 @@ class PortageConfigProxy(object):
                 obj.repositories = [RepoConfigProxy(x.name, x.location)
                                     for x in c.repositories]
                 queue.put(obj)
-            except Exception as e:
+            except Exception:
                 queue.put(None)
+
         queue = multiprocessing.Queue()
         p = multiprocessing.Process(target=target, args=(chroot, queue))
         p.start()
@@ -582,6 +639,7 @@ class PortageConfigProxy(object):
     def __str__(self):
         return "EmergeConfig"
 
+
 class VariableClEmergeConfig(ReadonlyVariable):
     """
     Emerge config object
@@ -593,18 +651,20 @@ class VariableClEmergeConfig(ReadonlyVariable):
         try:
             if self.systemRoot == '/':
                 from portage.package.ebuild.config import config
+
                 config.__str__ = lambda self: "EmergeConfig"
                 with stderr_devnull():
                     c = config()
-                if c.repositories.repoLocationList(): # and c["LINGUAS"]:
+                if c.repositories.repoLocationList():  # and c["LINGUAS"]:
                     return c
             else:
                 c = PortageConfigProxy.getconfig(self.systemRoot)
                 return c or ""
-        except Exception as e:
+        except Exception:
             pass
         return ""
 
+
 class VariableClEmergeDefaultOpts(ReadonlyVariable):
     """
     EMERGE_DEFAULT_OPTS
@@ -615,14 +675,14 @@ class VariableClEmergeDefaultOpts(ReadonlyVariable):
         if emerge_config:
             return emerge_config['EMERGE_DEFAULT_OPTS'].encode('UTF-8')
         else:
-            emergeInfo = self.Get('cl_emerge_info')
-            for line in filter(lambda x:x.startswith("EMERGE_DEFAULT_OPTS="),
-                               emergeInfo):
+            emerge_info = self.Get('cl_emerge_info')
+            for line in filter(lambda x: x.startswith("EMERGE_DEFAULT_OPTS="),
+                               emerge_info):
                 key, op, value = line.partition('=')
-                for quote in ("'",'"'):
+                for quote in ("'", '"'):
                     if value.startswith(quote):
                         value = value[1:-1]
-                return value.replace(r'\"','"')
+                return value.replace(r'\"', '"')
         return ""
 
 
@@ -631,9 +691,9 @@ class VariableClTemplatesLocate(Variable):
     Выбранные типы хранилищ шаблонов
     """
     type = "choice-list"
-    #value = ['overlay','local','remote','clt']
+    # value = ['overlay','local','remote','clt']
     element = "selecttable"
-    opt = ["-T","--templates"]
+    opt = ["-T", "--templates"]
     metavalue = "TEMPLATES"
     untrusted = True
 
@@ -645,8 +705,7 @@ class VariableClTemplatesLocate(Variable):
 
     def init(self):
         self.label = _("Templates location")
-        self.help = _("select location for templates %s") \
-                      %",".join(self.get())
+        self.help = _("select location for templates %s") % ",".join(self.get())
 
     def get(self):
         vals = \
@@ -657,8 +716,9 @@ class VariableClTemplatesLocate(Variable):
             return vals + ['clt']
 
     def choice(self):
-        return map(lambda x:(x,self.descriptionMap.get(x,x)),
-               self.get())
+        return map(lambda x: (x, self.descriptionMap.get(x, x)),
+                   self.get())
+
 
 class VariableClTemplatePathUse(ReadonlyVariable):
     """
@@ -667,16 +727,19 @@ class VariableClTemplatePathUse(ReadonlyVariable):
     type = 'list'
 
     def get(self):
-        return self.Select('cl_template_path',where='cl_template_location',
-                          _in=self.Get('cl_templates_locate'))
+        return self.Select('cl_template_path', where='cl_template_location',
+                           _in=self.Get('cl_templates_locate'))
+
 
 class VariableClTemplateCltSet(ReadonlyVariable):
     """
     Использовать clt шаблоны для настройки системы
     """
+
     def get(self):
         return "on" if "clt" in self.Get('cl_templates_locate') else "off"
 
+
 class VariableClEnvDebugSet(Variable):
     """
     Переменная для включения отладки
@@ -684,6 +747,7 @@ class VariableClEnvDebugSet(Variable):
     type = "bool"
     value = "on"
 
+
 class VariableClMakeProfile(Variable):
     """
     Путь до актуального make.profile
